package com.covas.Resources;

import java.nio.charset.StandardCharsets;
import java.util.UUID;

import javax.annotation.security.RolesAllowed;
import javax.inject.Inject;
import javax.ws.rs.core.SecurityContext;
import javax.ws.rs.CookieParam;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

import com.covas.Entity.UsersEntity;
import com.covas.Json.UserSingle;

import org.eclipse.microprofile.jwt.Claims;
import org.eclipse.microprofile.jwt.JsonWebToken;
import org.jboss.logging.Logger;
import org.postgresql.shaded.com.ongres.scram.common.bouncycastle.base64.Base64;

import io.quarkus.hibernate.orm.panache.PanacheQuery;


@Produces(MediaType.APPLICATION_JSON)
@Path("users")
public class UsersRessources {
    private static final Logger LOGGER = Logger.getLogger(UsersRessources.class);
    @Inject
    JsonWebToken jwt;
    
    @GET
    @RolesAllowed("Admin")
    public Response getUsers(){
        return Response.ok(UsersEntity.listAll()).build();
    }

    @GET
    @RolesAllowed("Admin")
    @Path("{id}")
    public Response getSingleUser(@PathParam("id") String id){
        UUID uid = UUID.fromString(id);
        UsersEntity users = UsersEntity.findById(uid);
        if(users == null){
            return Response.status(Response.Status.NOT_FOUND).build();
        }
        return Response.ok(users).build();
    }

    @GET
    @RolesAllowed("User")
    @Path("info")
    public Response getInfoUser(@Context SecurityContext ctx,  @CookieParam("user") String userCookie){
        if(!ctx.getUserPrincipal().getName().equals(jwt.getName())){
            return Response.status(Response.Status.INTERNAL_SERVER_ERROR).build();
        }
        UUID kid = UUID.fromString(jwt.getClaim(Claims.kid));
        UsersEntity user = UsersEntity.findById(kid);
        if (user == null){
            return Response.status(Response.Status.NOT_FOUND).build();
        }
        String name = new String(Base64.decode(userCookie), StandardCharsets.UTF_8);
        if(!name.equals(user.pseudo)){
            return Response.status(Response.Status.FORBIDDEN).build();
        }
        return Response.ok(new UserSingle(user.name, user.pseudo, user.firstName)).build();
    }    
}
